@@ -52,16 +52,17 @@ filter <- function(.data, ...) {
   subset(.data, ...)
 }
 
-left_join <- function(x, y, by, ...) {
+left_join <- function(x, y, by) {
   if (rlang::is_named(by)) {
     by_x <- names(by)
     by_y <- unname(by)
   } else {
     by_x <- by_y <- by
   }
-  res <- as_tibble(merge(x, y, by.x = by_x, by.y = by_y, all.x = TRUE, ...))
-  res <- arrange(res, pos_id)
 
+  res <- merge(x, y, by.x = by_x, by.y = by_y, all.x = TRUE, sort = FALSE) %>%
+    arrange_pos_id()
+  res <- new_tibble(res, nrow = nrow(res))
   # dplyr::left_join set unknown list columns to NULL, merge sets them
   # to NA
   if (exists("child", res) && any(is.na(res$child))) {
