@@ -15,6 +15,7 @@
 #'
 #' * version 1: Before fix mentioned in #419.
 #' * version 2: After #419.
+#' # version 3: After #582.
 #'
 #' The following utilities are available:
 #'
@@ -42,9 +43,27 @@ parser_version_get <- function() {
 
 #' @rdname parser_version_set
 parser_version_find <- function(pd) {
-  ifelse(any(pd$token == "equal_assign"), 2, 1)
+  ifelse(any(pd$token == "equal_assign"),
+    2,
+    ifelse(any(pd$token == "expr_or_assign_or_help"),
+      3,
+      1
+    )
+  )
 }
 
 
-
+#' The elements that are added to this environment are:
+#'
+#' @details
+#' * `parser_version`: Needed to dispatch between parser versions, see
+#'   [parser_version_set()] for details.
+#' * `stylerignore`: A tibble with parse data containing tokens that fall within
+#'   a stylerignore sequence. This is used after serializing the flattened
+#'   parse table to apply the initial formatting to these tokens. See
+#'   [stylerignore] for details.
+#' * `any_stylerignore`: Whether there is any stylerignore marker. The idea is
+#'   to check early in the runtime if this is the case and then if so, take
+#'   as many short-cuts as possible. See [stylerignore] for details.
+#' @keywords internal
 env_current <- rlang::new_environment(parent = rlang::empty_env())
