@@ -5,3 +5,11 @@ a %>%
   g_out()
 
 a <- function(jon_the_pipe) {}
+
+x %>%
+  # break
+  call()
+
+
+y %>%
+  call() # mor
