@@ -153,47 +153,62 @@ test_that("messages (via cat()) of style_file are correct", {
       list(cli.unicode = encoding == "utf8"),
       {
         # Message if scope > line_breaks and code changes
-        output <- catch_style_file_output(c(
+        output <- catch_style_file_output(file.path(
           "public-api",
           "xyzdir-dirty",
           "dirty-sample-with-scope-tokens.R"
-        ), encoding = encoding)
+        ))
         expect_known_value(
           output,
           testthat_file(paste0(
             "public-api/xyzdir-dirty/dirty-reference-with-scope-tokens-",
             encoding
-          ))
+          )),
+          update = getOption("styler.test_dir_writable", TRUE)
         )
 
         # No message if scope > line_breaks and code does not change
-        output <- catch_style_file_output(c(
+        output <- catch_style_file_output(file.path(
           "public-api", "xyzdir-dirty", "clean-sample-with-scope-tokens.R"
-        ), encoding = encoding)
+        ))
         expect_known_value(
           output,
           testthat_file(paste0(
             "public-api/xyzdir-dirty/clean-reference-with-scope-tokens-",
             encoding
-          ))
+          )),
+          update = getOption("styler.test_dir_writable", TRUE)
         )
 
         # No message if scope <= line_breaks even if code is changed.
-        output <- catch_style_file_output(c(
+        output <- catch_style_file_output(file.path(
           "public-api", "xyzdir-dirty", "dirty-sample-with-scope-spaces.R"
-        ), encoding = encoding)
+        ))
         expect_known_value(
           output,
           testthat_file(paste0(
             "public-api/xyzdir-dirty/dirty-reference-with-scope-spaces-",
             encoding
-          ))
+          )),
+          update = getOption("styler.test_dir_writable", TRUE)
         )
       }
     )
   }
 })
 
+test_that("Messages can be suppressed", {
+  withr::with_options(
+    list(styler.quiet = TRUE),
+    {
+      output <- catch_style_file_output(file.path(
+        "public-api", "xyzdir-dirty", "dirty-sample-with-scope-spaces.R"
+      ))
+      expect_equal(output, character(0))
+    }
+  )
+})
+
 context("public API - Rmd in style_dir()")
 
 test_that("styler can style R and Rmd files via style_dir()", {
@@ -312,3 +327,99 @@ test_that("styler can style Rnw files only via style_pkg()", {
   expect_true(any(grepl("random.Rnw", msg, fixed = TRUE)))
   expect_false(any(grepl("RcppExports.R", msg, fixed = TRUE)))
 })
+
+test_that("dry run options work:", {
+  path <- test_path("public-api/dry/unstyled.R")
+  # test the testing function
+  expect_error(test_dry(path, style_file, styled = TRUE))
+
+  # real tests
+  ## R
+  test_dry(path, style_file)
+  path <- test_path("public-api/dry/styled.R")
+  test_dry(path, style_file, styled = TRUE)
+
+  ## Rmd
+  test_dry(test_path("public-api/dry/unstyled.Rmd"), style_file, styled = FALSE)
+  test_dry(test_path("public-api/dry/styled.Rmd"), style_file, styled = TRUE)
+
+  ## Rmd
+  test_dry(test_path("public-api/dry/unstyled.Rnw"), style_file, styled = FALSE)
+  test_dry(test_path("public-api/dry/styled.Rnw"), style_file, styled = TRUE)
+})
+
+test_that("base indention works", {
+  # for single-line strings
+  n_spaces <- 5
+  text_in <- "x<- function() NULL"
+  expect_equal(
+    style_text(text_in, base_indention = n_spaces),
+    construct_vertical(paste0(add_spaces(n_spaces), style_text(text_in)))
+  )
+  # for multi-line strings
+  text_in <- c(
+    "x<- function()",
+    '"here\nis"',
+    "NULL",
+    "1+ 1"
+  )
+  text_out <- c(
+    "     x <- function() {",
+    '       "here',
+    'is"',
+    "     }",
+    "     NULL",
+    "     1 + 1"
+  )
+  expect_equal(
+    as.character(style_text(text_in, base_indention = n_spaces)),
+    text_out
+  )
+})
+
+test_that("scope can be specified as is", {
+  capture_output(expect_false({
+    styled <- style_pkg(testthat_file("public-api", "xyzpackage"), scope = I("spaces"))
+    any(styled$changed)
+  }))
+
+  file <- testthat_file("public-api", "xyzpackage", "R", "hello-world.R")
+  capture_output(expect_false({
+    styled <- style_file(file, scope = I("line_breaks"))
+    any(styled$changed)
+  }))
+  expect_equal(
+    style_text(c("1+14;x=2"), scope = I(c("line_breaks", "tokens"))),
+    construct_vertical(c("1+14", "x<-2"))
+  )
+})
+
+test_that("Can properly determine style_after_saving", {
+  withr::with_envvar(list(save_after_styling = TRUE), {
+    expect_warning(op <- save_after_styling_is_active(), "is depreciated")
+    expect_equal(op, TRUE)
+  })
+
+  withr::with_envvar(list(save_after_styling = FALSE), {
+    expect_warning(op <- save_after_styling_is_active(), "is depreciated")
+    expect_equal(op, FALSE)
+  })
+
+
+  withr::with_options(list(styler.save_after_styling = TRUE), {
+    expect_silent(op <- save_after_styling_is_active())
+    expect_equal(op, TRUE)
+  })
+
+  withr::with_options(list(styler.save_after_styling = TRUE), {
+    withr::with_envvar(list(save_after_styling = FALSE), {
+      expect_warning(op <- save_after_styling_is_active(), "is depreciated")
+      expect_equal(op, TRUE)
+    })
+  })
+
+  withr::with_options(list(styler.save_after_styling = FALSE), {
+    expect_silent(op <- save_after_styling_is_active())
+    expect_equal(op, FALSE)
+  })
+})
